Index: chrome/test/automation/automation_proxy_uitest.h |
diff --git a/chrome/test/automation/automation_proxy_uitest.h b/chrome/test/automation/automation_proxy_uitest.h |
index 4e6d09563359280187ecfaa5baa235d591349350..55da8cc8ee0b3ed7bc4268c403faab24b594f3c4 100644 |
--- a/chrome/test/automation/automation_proxy_uitest.h |
+++ b/chrome/test/automation/automation_proxy_uitest.h |
@@ -112,17 +112,16 @@ class ExternalTabUITestMockClient : public AutomationProxy { |
class ExternalTabUITest : public UITest { |
public: |
ExternalTabUITest() : UITest(MessageLoop::TYPE_UI) {} |
// Override UITest's CreateProxyLauncher to provide the unit test |
// with our special implementation of AutomationProxy. |
- // This function is called from within UITest::SetUp(). |
- virtual ProxyLauncher* CreateProxyLauncher(); |
+ // This function is called from within UITest::LaunchBrowserAndServer. |
+ virtual AutomationProxy* CreateAutomationProxy(int execution_timeout); |
protected: |
// Filtered Inet will override automation callbacks for network resources. |
virtual bool ShouldFilterInet() { |
return false; |
} |
ExternalTabUITestMockClient* mock_; |
- std::string channel_id_; // Channel id of automation proxy. |
}; |
#endif // CHROME_TEST_AUTOMATION_AUTOMATION_PROXY_UITEST_H_ |
@@ -112,17 +112,16 @@ class ExternalTabUITestMockClient : public AutomationProxy { |
public: |
ExternalTabUITest() : UITest(MessageLoop::TYPE_UI) {} |
- // Override UITest's CreateProxyLauncher to provide the unit test |
+ // Override UITest's CreateAutomationProxy to provide the unit test |
// with our special implementation of AutomationProxy. |